==> inti-test-1.2.0-b2b9a1.tar: src/TestCase/ApplicationTestTrait.php <==
<?php
/** @noinspection PhpFullyQualifiedNameUsageInspection */
declare(strict_types=1);

namespace Inti\Test\TestCase;

use Inti\Test\Emitter\TestEmitter;
use Laminas\Diactoros\ServerRequestFactory;
use Laminas\HttpHandlerRunner\Emitter\EmitterInterface;
use Laminas\Stdlib\ArrayUtils;
use Mezzio\Application;
use Mezzio\Container\ApplicationConfigInjectionDelegator;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

use function array_filter;
use function explode;

/**
 * Trait ApplicationTestCase
 *
 * @package Inti\Test\TestCase
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-test
 */
trait ApplicationTestTrait
{
    use ContainerTestTrait {
        ContainerTestTrait::createConfig as containerCreateConfig;
    }

    protected array $application_providers = [
        \Mezzio\ConfigProvider::class,
        \Mezzio\Router\ConfigProvider::class,
        \Mezzio\Router\FastRouteRouter\ConfigProvider::class,
    ];

    protected array $application_config = [
        'dependencies' => [
            'delegators' => [
                Application::class => [
                    ApplicationConfigInjectionDelegator::class,
                ],
            ],
            'invokables' => [
                EmitterInterface::class => TestEmitter::class,
            ],
        ],
    ];

    protected function createConfig(array $config = []): array
    {
        $original_providers = $this->providers ?? null;

        /** @noinspection PhpUndefinedFieldInspection */
        $this->providers = ArrayUtils::merge($this->application_providers, $original_providers ?? []);
        $config = ArrayUtils::merge($this->application_config, $config);

        $config = $this->containerCreateConfig($config);

        $this->providers = $original_providers;

        return $config;
    }

    protected function createApplication(array $config = []): Application
    {
        $container = $this->createContainer($config);
        return $container->get(Application::class);
    }

    protected function runApplication(
        array $config = [],
        string $path = '/',
        string $method = 'GET'
    ): ResponseInterface
    {
        /** @noinspection PhpExpressionResultUnusedInspection */
        @list($path, $query) = explode('?', $path, 2);

        $_SERVER = ArrayUtils::merge($_SERVER, [
            'HTTP_HOST' => $this->hostname ?? 'inti.dev',
            'QUERY_STRING' => $query ?? '',
            'REQUEST_METHOD' => $method,
            'REQUEST_URI' => $path,
        ]);

        foreach (array_filter(explode('&', $query ?? '')) as $param) {
            /** @noinspection PhpExpressionResultUnusedInspection */
            @list($name, $value) = explode('=', $param, 2);
            $_GET[$name] = $value ?? '';
        }

        $request = ServerRequestFactory::fromGlobals();

        $config['dependencies']['services'][ServerRequestInterface::class] = fn() => $request;

        $application = $this->createApplication($config);
        $application->run();

        /** @var TestEmitter $emitter */
        $emitter = $this->container->get(EmitterInterface::class);
        return $emitter->getReponse();
    }
}

==> inti-test-1.2.1-751410.tar: src/TestCase/ApplicationTestTrait.php <==
<?php
declare(strict_types=1);

namespace Inti\Test\TestCase;

use Inti\App\ConfigProvider;
use Inti\Test\Emitter\TestEmitter;
use Laminas\Diactoros\ServerRequestFactory;
use Laminas\HttpHandlerRunner\Emitter\EmitterInterface;
use Laminas\Stdlib\ArrayUtils;
use Mezzio\Application;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

use function array_filter;
use function explode;

/**
 * Trait ApplicationTestCase
 *
 * @package Inti\Test\TestCase
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-test
 */
trait ApplicationTestTrait
{
    use ContainerTestTrait {
        ContainerTestTrait::createConfig as containerCreateConfig;
    }

    protected array $application_providers = [
        ConfigProvider::class,
    ];

    protected array $application_config = [
        'dependencies' => [
            'invokables' => [
                EmitterInterface::class => TestEmitter::class,
            ],
        ],
    ];

    protected function createConfig(array $config = []): array
    {
        $original_providers = $this->providers ?? null;

        /** @noinspection PhpUndefinedFieldInspection */
        $this->providers = ArrayUtils::merge($this->application_providers, $original_providers ?? []);
        $config = ArrayUtils::merge($this->application_config, $config);

        $config = $this->containerCreateConfig($config);

        $this->providers = $original_providers;

        return $config;
    }

    protected function createApplication(array $config = []): Application
    {
        $container = $this->createContainer($config);
        return $container->get(Application::class);
    }

    protected function runApplication(
        array $config = [],
        string $path = '/',
        string $method = 'GET'
    ): ResponseInterface
    {
        /** @noinspection PhpExpressionResultUnusedInspection */
        @list($path, $query) = explode('?', $path, 2);

        $_SERVER = ArrayUtils::merge($_SERVER, [
            'HTTP_HOST' => $this->hostname ?? 'inti.dev',
            'QUERY_STRING' => $query ?? '',
            'REQUEST_METHOD' => $method,
            'REQUEST_URI' => $path,
        ]);

        foreach (array_filter(explode('&', $query ?? '')) as $param) {
            /** @noinspection PhpExpressionResultUnusedInspection */
            @list($name, $value) = explode('=', $param, 2);
            $_GET[$name] = $value ?? '';
        }

        $request = ServerRequestFactory::fromGlobals();

        $config['dependencies']['services'][ServerRequestInterface::class] = fn() => $request;

        $application = $this->createApplication($config);
        $application->run();

        /** @var TestEmitter $emitter */
        $emitter = $this->container->get(EmitterInterface::class);
        return $emitter->getReponse();
    }
}
